<?php

/**
 * @file
 * Holds the administration page and its helper functions.
 */

/**
 * Form callback for configuration page.
 */
function better_batch_settings_form() {
  $form = array();

  // Fieldset for general improvement settings.
  $form['general'] = array(
    '#type' => 'fieldset',
    '#title' => t('General improvements'),
  );
  // Global Batch jobs.
  $form['general']['better_batch_global_jobs'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('better_batch_global_jobs', FALSE),
    '#title' => t('Global batch jobs (Experimental!)'),
    '#description' => t('Progress pages of global batches are reachable by multiple users. Access validation depends on the users permission to visit the batch source page. Only the batch owner pushes the process, other users only get the current batch state.'),
  );
  // Session independence
  $form['general']['better_batch_session_independence'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('better_batch_session_independence', FALSE),
    '#title' => t('Session independence'),
    '#description' => t('The dependence of batch jobs on sessions will be released and bound to the user instead. So batch jobs are still available after re-login.'),
  );
  // Unique non-concurrent Batch jobs.
  $form['general']['better_batch_unique_jobs'] = array(
    '#type' => 'checkbox',
    '#default_value' => variable_get('better_batch_unique_jobs', FALSE),
    '#title' => t('Unique non-concurrent batch jobs'),
    '#description' => t('Equal batch jobs will not be started twice if there is one already running.'),
  );

  // Progress Bar style.
  $form['style'] = array(
    '#type' => 'fieldset',
    '#title' => t('Progress bar style'),
  );
  // Inner progress bar style.
  $form['style']['better_batch_inner_style'] = array(
    '#type' => 'select',
    '#title' => t('Inner progress bar style'),
    '#options' => _better_batch_inner_styles(),
    '#default_value' => variable_get('better_batch_inner_style', 'default'),
    '#description' => t('Change the style of the inner progress bar element.'),
  );
  $form['style']['better_batch_inner_style_color'] = array(
    '#type' => 'textfield',
    '#title' => t('Inner progress bar color'),
    '#default_value' => variable_get('better_batch_inner_style_color', '#0072B9'),
    '#size' => 10,
    '#maxlength' => 7,
    '#description' => t('Change the style of the inner progress bar element.'),
  );
  $form['style']['better_batch_inner_style_image'] = array(
    '#type' => 'textfield',
    '#title' => t('Custom image'),
    '#default_value' => variable_get('better_batch_inner_style_image', ''),
    '#description' => t('Image of the inner progress bar element.'),
  );
  return system_settings_form($form);
}

/**
 * Returns an array of inner progress bar styles.
 */
function _better_batch_inner_styles() {
  $images_path = base_path() . drupal_get_path('module', 'better_batch') . '/images/';
  $styles = array(
    'default' => t('Default'),
    $images_path . 'progress-blue.gif' => t('Drupal 7, Default'),
    $images_path . 'progress-blue-backwards.gif' => t('Drupal 7, Backwards'),
    $images_path . 'progress-grayed.gif' => t('Drupal 7, Grayed'),
    $images_path . 'progress-light-grayed.gif' => t('Drupal 7, (light) Grayed'),
    $images_path . 'progress-inverted.gif' => t('Drupal 7, Inverted'),
    $images_path . 'progress-red.gif' => t('Drupal 7, Red'),
    $images_path . 'progress-green.gif' => t('Drupal 7, Green'),
    $images_path . 'progress-yellow.gif' => t('Drupal 7, Yellow'),
    $images_path . 'progress-purple.gif' => t('Drupal 7, Purple'),
    'color' => t('Custom color'),
    'image' => t('Custom image'),
  );
  return $styles;
}
